<a id="mypy-boto3-kendra"></a>

# mypy-boto3-kendra

[![PyPI - mypy-boto3-kendra](https://img.shields.io/pypi/v/mypy-boto3-kendra.svg?color=blue)](https://pypi.org/project/mypy-boto3-kendra)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-kendra.svg?color=blue)](https://pypi.org/project/mypy-boto3-kendra)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-kendra?color=blue)](https://pypistats.org/packages/mypy-boto3-kendra)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.kendra 1.19.2](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/kendra.html#kendra)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-kendra docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-kendra](#mypy-boto3-kendra)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `kendra` service.

```bash
python -m pip install boto3-stubs[kendra]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[kendra]` in your environment:
  `python -m pip install 'boto3-stubs[kendra]'`

Both type checking and auto-complete should work for `kendra` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[kendra]` in your environment:
  `python -m pip install 'boto3-stubs[kendra]'`

Both type checking and auto-complete should work for `kendra` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[kendra]` in your environment:
  `python -m pip install 'boto3-stubs[kendra]'`
- Run `mypy` as usual

Type checking should work for `kendra` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[kendra]` in your environment:
  `python -m pip install 'boto3-stubs[kendra]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `kendra` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`kendraClient` provides annotations for `boto3.client("kendra")`.

```python
import boto3

from mypy_boto3_kendra import kendraClient

client: kendraClient = boto3.client("kendra")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: kendraClient = session.client("kendra")
```

<a id="literals"></a>

### Literals

`mypy_boto3_kendra.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_kendra.literals import (
    AdditionalResultAttributeValueTypeType,
    ConfluenceAttachmentFieldNameType,
    ConfluenceBlogFieldNameType,
    ConfluencePageFieldNameType,
    ConfluenceSpaceFieldNameType,
    ConfluenceVersionType,
    ContentTypeType,
    DataSourceStatusType,
    DataSourceSyncJobStatusType,
    DataSourceTypeType,
    DatabaseEngineTypeType,
    DocumentAttributeValueTypeType,
    DocumentStatusType,
    ErrorCodeType,
    FaqFileFormatType,
    FaqStatusType,
    HighlightTypeType,
    IndexEditionType,
    IndexStatusType,
    KeyLocationType,
    ModeType,
    OrderType,
    PrincipalMappingStatusType,
    PrincipalTypeType,
    QueryIdentifiersEnclosingOptionType,
    QueryResultTypeType,
    QuerySuggestionsBlockListStatusType,
    QuerySuggestionsStatusType,
    ReadAccessTypeType,
    RelevanceTypeType,
    SalesforceChatterFeedIncludeFilterTypeType,
    SalesforceKnowledgeArticleStateType,
    SalesforceStandardObjectNameType,
    ScoreConfidenceType,
    ServiceNowAuthenticationTypeType,
    ServiceNowBuildVersionTypeType,
    SharePointVersionType,
    SortOrderType,
    ThesaurusStatusType,
    UserContextPolicyType,
    UserGroupResolutionModeType,
    WebCrawlerModeType,
    ServiceName,
)

def check_value(value: AdditionalResultAttributeValueTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_kendra.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_kendra.type_defs import (
    AccessControlListConfigurationTypeDef,
    AclConfigurationTypeDef,
    AdditionalResultAttributeTypeDef,
    AdditionalResultAttributeValueTypeDef,
    AttributeFilterTypeDef,
    AuthenticationConfigurationTypeDef,
    BasicAuthenticationConfigurationTypeDef,
    BatchDeleteDocumentRequestRequestTypeDef,
    BatchDeleteDocumentResponseFailedDocumentTypeDef,
    BatchDeleteDocumentResponseTypeDef,
    BatchGetDocumentStatusRequestRequestTypeDef,
    BatchGetDocumentStatusResponseErrorTypeDef,
    BatchGetDocumentStatusResponseTypeDef,
    BatchPutDocumentRequestRequestTypeDef,
    BatchPutDocumentResponseFailedDocumentTypeDef,
    BatchPutDocumentResponseTypeDef,
    CapacityUnitsConfigurationTypeDef,
    ClearQuerySuggestionsRequestRequestTypeDef,
    ClickFeedbackTypeDef,
    ColumnConfigurationTypeDef,
    ConfluenceAttachmentConfigurationTypeDef,
    ConfluenceAttachmentToIndexFieldMappingTypeDef,
    ConfluenceBlogConfigurationTypeDef,
    ConfluenceBlogToIndexFieldMappingTypeDef,
    ConfluenceConfigurationTypeDef,
    ConfluencePageConfigurationTypeDef,
    ConfluencePageToIndexFieldMappingTypeDef,
    ConfluenceSpaceConfigurationTypeDef,
    ConfluenceSpaceToIndexFieldMappingTypeDef,
    ConnectionConfigurationTypeDef,
    CreateDataSourceRequestRequestTypeDef,
    CreateDataSourceResponseTypeDef,
    CreateFaqRequestRequestTypeDef,
    CreateFaqResponseTypeDef,
    CreateIndexRequestRequestTypeDef,
    CreateIndexResponseTypeDef,
    CreateQuerySuggestionsBlockListRequestRequestTypeDef,
    CreateQuerySuggestionsBlockListResponseTypeDef,
    CreateThesaurusRequestRequestTypeDef,
    CreateThesaurusResponseTypeDef,
    DataSourceConfigurationTypeDef,
    DataSourceGroupTypeDef,
    DataSourceSummaryTypeDef,
    DataSourceSyncJobMetricTargetTypeDef,
    DataSourceSyncJobMetricsTypeDef,
    DataSourceSyncJobTypeDef,
    DataSourceToIndexFieldMappingTypeDef,
    DataSourceVpcConfigurationTypeDef,
    DatabaseConfigurationTypeDef,
    DeleteDataSourceRequestRequestTypeDef,
    DeleteFaqRequestRequestTypeDef,
    DeleteIndexRequestRequestTypeDef,
    DeletePrincipalMappingRequestRequestTypeDef,
    DeleteQuerySuggestionsBlockListRequestRequestTypeDef,
    DeleteThesaurusRequestRequestTypeDef,
    DescribeDataSourceRequestRequestTypeDef,
    DescribeDataSourceResponseTypeDef,
    DescribeFaqRequestRequestTypeDef,
    DescribeFaqResponseTypeDef,
    DescribeIndexRequestRequestTypeDef,
    DescribeIndexResponseTypeDef,
    DescribePrincipalMappingRequestRequestTypeDef,
    DescribePrincipalMappingResponseTypeDef,
    DescribeQuerySuggestionsBlockListRequestRequestTypeDef,
    DescribeQuerySuggestionsBlockListResponseTypeDef,
    DescribeQuerySuggestionsConfigRequestRequestTypeDef,
    DescribeQuerySuggestionsConfigResponseTypeDef,
    DescribeThesaurusRequestRequestTypeDef,
    DescribeThesaurusResponseTypeDef,
    DocumentAttributeTypeDef,
    DocumentAttributeValueCountPairTypeDef,
    DocumentAttributeValueTypeDef,
    DocumentInfoTypeDef,
    DocumentMetadataConfigurationTypeDef,
    DocumentRelevanceConfigurationTypeDef,
    DocumentTypeDef,
    DocumentsMetadataConfigurationTypeDef,
    FacetResultTypeDef,
    FacetTypeDef,
    FaqStatisticsTypeDef,
    FaqSummaryTypeDef,
    GetQuerySuggestionsRequestRequestTypeDef,
    GetQuerySuggestionsResponseTypeDef,
    GoogleDriveConfigurationTypeDef,
    GroupMembersTypeDef,
    GroupOrderingIdSummaryTypeDef,
    GroupSummaryTypeDef,
    HierarchicalPrincipalTypeDef,
    HighlightTypeDef,
    IndexConfigurationSummaryTypeDef,
    IndexStatisticsTypeDef,
    JsonTokenTypeConfigurationTypeDef,
    JwtTokenTypeConfigurationTypeDef,
    ListDataSourceSyncJobsRequestRequestTypeDef,
    ListDataSourceSyncJobsResponseTypeDef,
    ListDataSourcesRequestRequestTypeDef,
    ListDataSourcesResponseTypeDef,
    ListFaqsRequestRequestTypeDef,
    ListFaqsResponseTypeDef,
    ListGroupsOlderThanOrderingIdRequestRequestTypeDef,
    ListGroupsOlderThanOrderingIdResponseTypeDef,
    ListIndicesRequestRequestTypeDef,
    ListIndicesResponseTypeDef,
    ListQuerySuggestionsBlockListsRequestRequestTypeDef,
    ListQuerySuggestionsBlockListsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListThesauriRequestRequestTypeDef,
    ListThesauriResponseTypeDef,
    MemberGroupTypeDef,
    MemberUserTypeDef,
    OneDriveConfigurationTypeDef,
    OneDriveUsersTypeDef,
    PrincipalTypeDef,
    ProxyConfigurationTypeDef,
    PutPrincipalMappingRequestRequestTypeDef,
    QueryRequestRequestTypeDef,
    QueryResultItemTypeDef,
    QueryResultTypeDef,
    QuerySuggestionsBlockListSummaryTypeDef,
    RelevanceFeedbackTypeDef,
    RelevanceTypeDef,
    ResponseMetadataTypeDef,
    S3DataSourceConfigurationTypeDef,
    S3PathTypeDef,
    SalesforceChatterFeedConfigurationTypeDef,
    SalesforceConfigurationTypeDef,
    SalesforceCustomKnowledgeArticleTypeConfigurationTypeDef,
    SalesforceKnowledgeArticleConfigurationTypeDef,
    SalesforceStandardKnowledgeArticleTypeConfigurationTypeDef,
    SalesforceStandardObjectAttachmentConfigurationTypeDef,
    SalesforceStandardObjectConfigurationTypeDef,
    ScoreAttributesTypeDef,
    SearchTypeDef,
    SeedUrlConfigurationTypeDef,
    ServerSideEncryptionConfigurationTypeDef,
    ServiceNowConfigurationTypeDef,
    ServiceNowKnowledgeArticleConfigurationTypeDef,
    ServiceNowServiceCatalogConfigurationTypeDef,
    SharePointConfigurationTypeDef,
    SiteMapsConfigurationTypeDef,
    SortingConfigurationTypeDef,
    SqlConfigurationTypeDef,
    StartDataSourceSyncJobRequestRequestTypeDef,
    StartDataSourceSyncJobResponseTypeDef,
    StatusTypeDef,
    StopDataSourceSyncJobRequestRequestTypeDef,
    SubmitFeedbackRequestRequestTypeDef,
    SuggestionHighlightTypeDef,
    SuggestionTextWithHighlightsTypeDef,
    SuggestionTypeDef,
    SuggestionValueTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TextDocumentStatisticsTypeDef,
    TextWithHighlightsTypeDef,
    ThesaurusSummaryTypeDef,
    TimeRangeTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateDataSourceRequestRequestTypeDef,
    UpdateIndexRequestRequestTypeDef,
    UpdateQuerySuggestionsBlockListRequestRequestTypeDef,
    UpdateQuerySuggestionsConfigRequestRequestTypeDef,
    UpdateThesaurusRequestRequestTypeDef,
    UrlsTypeDef,
    UserContextTypeDef,
    UserGroupResolutionConfigurationTypeDef,
    UserTokenConfigurationTypeDef,
    WebCrawlerConfigurationTypeDef,
    WorkDocsConfigurationTypeDef,
)

def get_structure() -> AccessControlListConfigurationTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-kendra` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-kendra docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
